unit ciaURL;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls, ShellApi;

type
  TCiaURL = class(TCustomLabel)
  private
   FFilePath: string;
  protected
   FURL: string;
   FParameters: string;
   FHyperlink: string;
   FCaption: string;
   FHighlightColor: TColor;
   FOnHighLightOff: TNotifyEvent;
   FontColor: TColor;
   Timer: TTimer;
   procedure SetHighlightColor(const Value: TColor);
   procedure SetCaption(Value: string);
   procedure SetFilePath(Value: string);
   procedure SetURL(Value: string);
   procedure MouseMove(Shift: TShiftState; X, Y: Integer); override;
   procedure TimerEvent(Sender: TObject);
   procedure Loaded; override;
   procedure Paint; override;
  public
   procedure Click; override;
   constructor Create(AOwner: TComponent); override;
   destructor Destroy; override;
  published
   property Anchors;
   property OnMouseMove;
   property OnClick;
   property Visible;
   property AutoSize;
   property ShowHint;
   property Color;
   property Font;
   property Cursor default crHandPoint;
   property HighlightColor: TColor read FHighlightColor write SetHighlightColor;
   property Caption: string read FCaption write SetCaption;
   property FilePath: string read FFilePath write SetFilePath;
   property URL: string read FURL write SetURL;
   property Parameters: string read FParameters write FParameters;
   property Hyperlink: string read FHyperlink write FHyperlink;
   property OnHighLightOff: TNotifyEvent read FOnHighLightOff write FOnHighLightOff;
  end;

procedure Register;

implementation

procedure TCiaURL.Click;
var
   FileToOpen, ExeFile: string;
begin
   if Hyperlink <> '' then
   begin
      FileToOpen := FilePath + URL;
      SetLength(ExeFile, 1024);
      FindExecutable(PChar(FileToOpen), '', PChar(ExeFile));
      FileToOpen := FileToOpen + Hyperlink;
      if ShellExecute(0, 'open', PChar(ExeFile), PChar(FileToOpen), '', SW_SHOWNORMAL) <= 32 then
         MessageBeep(0);
   end
   else if ShellExecute(0, 'open', PChar(URL), PChar(Parameters), '', SW_SHOWNORMAL) <= 32 then
         MessageBeep(0);
   inherited Click;
end;

procedure TCiaURL.Paint;
begin
   if Caption = '' then
      Caption := Name;
   inherited Paint;
end;

procedure TCiaURL.SetUrl(Value: string);
begin
   if FURL <> Value then
   begin
      FURL := Value;
      if (Caption = '') or (Caption = Name) then
         Caption := FURL;
   end;
end;

procedure TCiaURL.SetFilePath(Value: string);
begin
   if FFilePath <> Value then
   begin
      FFilePath := Value;
      if (FFilePath <> '') and (FFilePath[length(FFilePath)] <> '\') then
         FFilePath := FFilePath + '\';
   end;
end;

procedure TCiaURL.SetHighlightColor(const Value: TColor);
begin
   if Value = clNone then
      FHighlightColor := Font.Color
   else
      FHighlightColor := Value;
end;

procedure TciaURL.SetCaption(Value: string);
begin
   if FCaption <> Value then
      FCaption := Value;
   inherited caption := FCaption;
end;

procedure TCiaURL.MouseMove(Shift: TShiftState; X, Y: Integer);
begin
   inherited MouseMove(Shift, X, Y);
   if not Assigned(Timer) then
   begin
      Font.Color := FHighlightColor;
      Timer := TTimer.Create(Self);
      Timer.Interval := 100;
      Timer.OnTimer := TimerEvent;
   end;
end;

procedure TCiaURL.TimerEvent(Sender : TObject);
var Pt : TPoint;
begin
   GetCursorPos(Pt);
   Pt := ScreentoClient(Pt);
   if not PtInRect(ClientRect, Pt) then
   begin
      Timer.Free;
      Timer := nil;
      Font.Color := FontColor;
      Repaint;
      if Assigned(OnHighLightOff) then
         OnHighLightOff(self);
  end;
end;

constructor TCiaURL.Create(AOwner: TComponent);
begin
   inherited Create(AOwner);
   FHighlightColor := clRed;
   Cursor := crHandPoint;
   Font.Style := Font.Style + [fsUnderline];
   Font.Color := clBlue;
   FURL := 'http://www.wilfried.dns2go.com/';
end;

procedure TCiaURL.Loaded;
begin
   inherited Loaded;
   FontColor := Font.Color;
   if not (csDesigning in ComponentState) and (FilePath = '') then
      FilePath := ExtractFilePath(Application.ExeName);
end;

destructor TciaURL.Destroy;
begin
   if Assigned(Timer) then
   begin
      Timer.Free;
      Timer := nil;
   end;
   inherited Destroy;
end;

procedure Register;
begin
  RegisterComponents('Cia', [TciaURL]);
end;

end.
